@@ -1,3 +1,4 @@
+"""Provider module for CloudNS"""
 from __future__ import absolute_import
 import logging
 
@@ -10,7 +11,8 @@ LOGGER = logging.getLogger(__name__)
 NAMESERVER_DOMAINS = ['cloudns.net']
 
 
-def ProviderParser(subparser):
+def provider_parser(subparser):
+    """Configure provider parser for CloudNS"""
     identity_group = subparser.add_mutually_exclusive_group()
     identity_group.add_argument(
         "--auth-id", help="specify user id for authentication")
@@ -25,27 +27,28 @@ def ProviderParser(subparser):
 
 
 class Provider(BaseProvider):
+    """Provider class for CloudNS"""
     def __init__(self, config):
         super(Provider, self).__init__(config)
         self.domain_id = None
         self.api_endpoint = 'https://api.cloudns.net'
 
-    def authenticate(self):
+    def _authenticate(self):
         payload = self._get('/dns/get-zone-info.json',
                             {'domain-name': self.domain})
         self.domain_id = payload['name']
         LOGGER.debug('authenticate: %s', payload)
 
-    def create_record(self, type, name, content):
+    def _create_record(self, rtype, name, content):
         # Skip execution if such a record already exists
-        existing_records = self.list_records(type, name, content)
-        if len(existing_records) > 0:
+        existing_records = self._list_records(rtype, name, content)
+        if existing_records:
             return True
 
         # Build parameters for adding a new record
         params = {
             'domain-name': self.domain_id,
-            'record-type': type,
+            'record-rtype': rtype,
             'host': self._relative_name(name),
             'record': content
         }
@@ -65,11 +68,11 @@ class Provider(BaseProvider):
         # Error handling is already covered by self._request
         return True
 
-    def list_records(self, type=None, name=None, content=None):
+    def _list_records(self, rtype=None, name=None, content=None):
         # Build parameters to make use of the built-in API filtering
         params = {'domain-name': self.domain_id}
-        if type:
-            params['type'] = type
+        if rtype:
+            params['type'] = rtype
         if name:
             params['host'] = self._relative_name(name)
 
@@ -95,10 +98,10 @@ class Provider(BaseProvider):
         LOGGER.debug('list_records: %s', records)
         return records
 
-    def update_record(self, identifier, type=None, name=None, content=None):
+    def _update_record(self, identifier, rtype=None, name=None, content=None):
         # Try to find record if no identifier was specified
         if not identifier:
-            identifier = self._find_record_identifier(type, name, None)
+            identifier = self._find_record_identifier(rtype, name, None)
 
         # Build parameters for updating an existing record
         params = {'domain-name': self.domain_id, 'record-id': identifier}
@@ -122,11 +125,11 @@ class Provider(BaseProvider):
         # Error handling is already covered by self._request
         return True
 
-    def delete_record(self, identifier=None, type=None, name=None, content=None):
+    def _delete_record(self, identifier=None, rtype=None, name=None, content=None):
         # Try to find record if no identifier was specified
         delete_record_id = []
         if not identifier:
-            records = self.list_records(type, name, content)
+            records = self._list_records(rtype, name, content)
             delete_record_id = [record['id'] for record in records]
         else:
             delete_record_id.append(identifier)
@@ -135,7 +138,7 @@ class Provider(BaseProvider):
 
         for record_id in delete_record_id:
             # Delete existing record by calling the ClouDNS API
-            payload = self._post(
+            self._post(
                 '/dns/delete-record.json', {'domain-name': self.domain_id, 'record-id': record_id})
 
         LOGGER.debug('delete_record: %s', True)
@@ -149,25 +152,27 @@ class Provider(BaseProvider):
                 'No valid authentication data passed, expected: auth-password')
 
         if self._get_provider_option('auth_id'):
-            return {'auth-id': self._get_provider_option('auth_id'), 'auth-password': self._get_provider_option('auth_password')}
-        elif self._get_provider_option('auth_subid'):
-            return {'sub-auth-id': self._get_provider_option('auth_subid'), 'auth-password': self._get_provider_option('auth_password')}
-        elif self._get_provider_option('auth_subuser'):
-            return {'sub-auth-user': self._get_provider_option('auth_subuser'), 'auth-password': self._get_provider_option('auth_password')}
-        elif self._get_provider_option('auth_id') or self._get_provider_option('auth_subid') or self._get_provider_option('auth_subuser'):
+            return {'auth-id': self._get_provider_option('auth_id'),
+                    'auth-password': self._get_provider_option('auth_password')}
+        if self._get_provider_option('auth_subid'):
+            return {'sub-auth-id': self._get_provider_option(
+                'auth_subid'), 'auth-password': self._get_provider_option('auth_password')}
+        if self._get_provider_option('auth_subuser'):
+            return {'sub-auth-user': self._get_provider_option(
+                'auth_subuser'), 'auth-password': self._get_provider_option('auth_password')}
+        if (self._get_provider_option('auth_id') or self._get_provider_option('auth_subid')
+                or self._get_provider_option('auth_subuser')):
             # All the options were passed with a fallback value, return an empty dictionary.
             return {}
-        else:
-            raise Exception(
-                'No valid authentication data passed, expected: auth-id, auth-subid, auth-subuser')
+        raise Exception(
+            'No valid authentication data passed, expected: auth-id, auth-subid, auth-subuser')
 
-    def _find_record_identifier(self, type, name, content):
-        records = self.list_records(type, name, content)
+    def _find_record_identifier(self, rtype, name, content):
+        records = self._list_records(rtype, name, content)
         LOGGER.debug('records: %s', records)
         if len(records) == 1:
             return records[0]['id']
-        else:
-            raise Exception('Record identifier could not be found.')
+        raise Exception('Record identifier could not be found.')
 
     def _request(self, action='GET', url='/', data=None, query_params=None):
         # Set default values for missing arguments
@@ -181,13 +186,14 @@ class Provider(BaseProvider):
             data.update(self._build_authentication_data())
 
         # Fire request against ClouDNS API and parse result as JSON
-        r = requests.request(action, self.api_endpoint +
-                             url, params=query_params, data=data)
-        r.raise_for_status()
-        payload = r.json()
+        response = requests.request(action, self.api_endpoint +
+                                    url, params=query_params, data=data)
+        response.raise_for_status()
+        payload = response.json()
 
         # Check ClouDNS specific status code and description
-        if 'status' in payload and 'statusDescription' in payload and payload['status'] != 'Success':
+        if ('status' in payload and 'statusDescription' in payload
+                and payload['status'] != 'Success'):
             raise Exception('ClouDNS API request has failed: ' +
                             payload['statusDescription'])
 
